package com.dcsoft.system.service;

import java.util.List;

import com.dcsoft.system.domain.SysBranch;
import com.dcsoft.system.domain.SysPeople;
import com.dcsoft.system.domain.SysSyncItem;
import com.dcsoft.system.domain.SysSyncRule;

/**
 * 同步规则Service接口
 *
 * @author nichun
 * @date 2024-01-11
 */
public interface ISysSyncRuleService
{
    /**
     * 查询同步规则
     *
     * @param id 同步规则主键
     * @return 同步规则
     */
    public SysSyncRule selectSysSyncRuleById(Long id);

    /**
     * 查询同步规则列表
     *
     * @param sysSyncRule 同步规则
     * @return 同步规则集合
     */
    public List<SysSyncRule> selectSysSyncRuleList(SysSyncRule sysSyncRule);

    /**
     * 新增同步规则
     *
     * @param sysSyncRule 同步规则
     * @return 结果
     */
    public int insertSysSyncRule(SysSyncRule sysSyncRule);

    /**
     * 修改同步规则
     *
     * @param sysSyncRule 同步规则
     * @return 结果
     */
    public int updateSysSyncRule(SysSyncRule sysSyncRule);

    /**
     * 批量删除同步规则
     *
     * @param ids 需要删除的同步规则主键集合
     * @return 结果
     */
    public int deleteSysSyncRuleByIds(Long[] ids);

    /**
     * 删除同步规则信息
     *
     * @param id 同步规则主键
     * @return 结果
     */
    public int deleteSysSyncRuleById(Long id);

    public int insetSysSyncRuleItem(SysSyncItem item);

    public int deleteSysSyncRuleItem(Long id);

    List<SysSyncItem> selectSysSyncRuleItem(Long id);

    public String addDept(SysBranch branch, String delete);

    public String  addPeople(SysPeople sysPeople, String update);

    /**
     * 查询园区对映的部门
     * @param tdGuid
     * @return
     */
    List<SysSyncItem> queryParkDept(String tdGuid);
}
